@@ -260,10 +260,13 @@ sub validate {
 
 sub _validate {
   my ($self, $data, $path, $schema) = @_;
-  my ($type) = (map { $schema->{$_} } grep { $schema->{$_} } qw( type allOf anyOf oneOf ))[0] || 'any';
+  my ($type) = (map { $schema->{$_} } grep { $schema->{$_} } qw( type allOf anyOf oneOf ))[0];
   my $check_all = grep { $schema->{$_} } qw( allOf oneOf );
   my @errors;
 
+  $type = 'object' if !$type and $schema->{properties};
+  $type ||= 'any';
+
   #$SIG{__WARN__} = sub { Carp::confess(Data::Dumper::Dumper($schema)) };
 
   if ($schema->{not}) {
@@ -404,7 +407,7 @@ sub _validate_properties {
     elsif ($required{$name}) {
       push @errors, E _path($path, $name), "Missing property.";
     }
-    elsif ($p->{required} and ref $p->{required} eq '') {
+    elsif ($p->{required} and $p->{required} eq '1') {
       push @errors, E _path($path, $name), "Missing property.";
     }
   }
